local LrLogger = import "LrLogger"
local LrDialogs = import "LrDialogs"

-- This class is used to implement the Catalog Deletion in Lightroom.
CatalogDeletion = {
    listOfUuidToDelete = {},  -- Array to store uuids of pictures to delete
}

-- Constructor
function CatalogDeletion:new()
    local obj = {}
    setmetatable(obj, self)
    self.__index = self
    return obj
end

-- Method to add a string to the array
function CatalogDeletion:add(value)
    table.insert(self.listOfUuidToDelete, value)
end

-- Method to process the deletion
function CatalogDeletion:process(catalog)
    for _, value in ipairs(self.listOfUuidToDelete) do
        logger:trace("searching for id: '" .. value .. "'")
        local photo = catalog:findPhotoByUuid(value)
        logger:trace("will update:" .. photo.localIdentifier)
        catalog:withWriteAccessDo("Change status",  function( context ) 
            -- do something that reads or writes catalog 
            photo:setRawMetadata("pickStatus", -1)
        end )
        
    end
    -- Ok, it is processed, so we can emty the array
    listOfUuidToDelete = {}
    -- we select thre right view
    catalog:withWriteAccessDo("Change status",  function( context ) 
        catalog:setActiveSources(catalog.kAllPhotos)
        catalog:setViewFilter({
            filtersActive = true,
            pick="rejected"
        })
    end )
    -- and inform the user to know what to do
    LrDialogs.message( LOC("$$$/PeaktoPlugin/catalogDeletion/message=Peakto has marked your deleted Photo as 'rejected'."), LOC("$$$/PeaktoPlugin/catalogDeletion/info=Now you need to delete these photos from Ligthroom Catalog, and then resynchronize your catalog in Peakto."),"info")
end
